@@ -11,8 +11,8 @@ from kyoslib_py.kyos_api import call_kyos_api_v1
 
 class HistoricalPrice:
     """
-    The HistoricalPrice class allows the storing and loading of historical price spot and forward data sent to a model
-    in csv format, in addition to historical_data_info.json.
+    The HistoricalPrice class allows the storing and loading of historical price spot and forward
+    data sent to a model in csv format, in addition to historical_data_info.json.
 
     Attributes:
         id (int): Price source id
@@ -20,14 +20,15 @@ class HistoricalPrice:
         type (string): spot' or 'forward'
         delivery_type (str): base', 'peak' or 'other' for forward prices, otherwise an empty list
         delivery_period_id (int): Id number of the delivery period for spot prices, otherwise an empty list
-        prices (DataFrame): Pandas dataframe containing the price data. Empty list until loaded with a method (see below).
+        prices (pd.DataFrame): Pandas dataframe containing the price data. Empty list until
+            loaded with a method (see below).
 
     Notes:
         All historical price profiles contained with the json file in the HistoricalData directory are loaded at the same
         time and stored within the class variable all_price_sources. The path of the subdirectory is also saved as a class
         variable (price_path).
 
-    Example:
+    Examples:
         >>> from kyoslib_py.historical_price import HistoricalPrice
         >>> HistoricalPrice()
         >>> HistoricalPrice.all_price_sources[0].id
@@ -39,7 +40,7 @@ class HistoricalPrice:
 
     def __init__(self, base_path=None):
         """
-        Constructor
+        Constructor method.
 
         Args:
             base_path (str, optional): String of the path of the main job directory. The HistoricalData subdirectory is assumed to be one level down.
@@ -85,7 +86,7 @@ class HistoricalPrice:
         Returns:
             (HistoricalPrice): Instance of the HistoricalPrice class with prices field populated with a DataFrame; date columns are sent as type DateTime.
 
-        Example:
+        Examples:
             >>> from kyoslib_py.historical_price import HistoricalPrice
             >>> HistoricalPrice()
             >>> HistoricalPrice.all_price_sources[0].load_all_prices()
@@ -131,9 +132,10 @@ class HistoricalPrice:
                 maturities returned if not provided
 
         Returns:
-            (prices_out): DataFrame of the relevant price data. Returned in same format as the input data, which depends on the data being of type 'forward' or 'spot'.
+            (pd.DataFrame): DataFrame of the relevant price data. Returned in same format as the
+                input data, which depends on the data being of type 'forward' or 'spot'.
 
-        Example:
+        Examples:
             --------
             >>> from kyoslib_py.historical_price import HistoricalPrice
             >>> HistoricalPrice()
@@ -219,10 +221,10 @@ class HistoricalPrice:
                 combination with one product and cannot be used with maturity.
 
         Returns:
-            (prices_df): DataFrame of the relevant price data in specific format which varies depending on the data being
-                spot or forward.
+            (pd.DataFrame): DataFrame of the relevant price data in specific format which varies
+                depending on the data being spot or forward.
 
-        Example:
+        Examples:
             --------
             >>> from kyoslib_py.historical_price import HistoricalPrice as Hp
             >>> prices = Hp.get_historical_prices_api(profile_id=15, price_type='spot')
@@ -260,7 +262,6 @@ class HistoricalPrice:
 
             # Forward data
             elif str.casefold(price_type) == 'forward':
-
                 nr_delivery_types = len(input_dict.get('delivery_types'))
                 if nr_delivery_types > 0:
                     del_type_dict = input_dict.get('delivery_types')[
@@ -364,7 +365,6 @@ class HistoricalPrice:
 
         # Filters for forward products
         if str.casefold(price_type) == 'forward':
-
             # Products filter
             if products is not None:
                 prod_str = f'{products[0].lower()}'
