@@ -10,10 +10,11 @@ import pandas as pd
 class CurrencySet:
     """
     This is the manager object of the currency class. This class loads the set of all available currencies.
+
     Attributes:
         currencies (list): list of objects
 
-    Example:
+    Examples:
         >>> from kyoslib_py.settings import CurrencySet
         >>> currency_set = CurrencySet.from_csv()
         >>> currency = currency_set.get_currency(1)
@@ -33,7 +34,8 @@ class CurrencySet:
     @staticmethod
     def from_csv(csv_path: str = './Input/currency.csv') -> object:
         """
-        this static method builds the CurrencySet object from xml
+        This static method builds the CurrencySet object from xml.
+
         Args:
             csv_path (str): path to currency.csv
 
@@ -49,7 +51,8 @@ class CurrencySet:
     @staticmethod
     def from_json(json_path: str) -> object:
         """
-        this static method builds the CurrencySet object from xml
+        This static method builds the CurrencySet object from xml.
+
         Args:
             json_path (str): path to currency.json
 
@@ -67,7 +70,6 @@ class CurrencySet:
 
     def get_currency(self, requested_currency_id: int) -> object:
         """
-
         Args:
             requested_currency_id (int): the currency id from the server
 
@@ -101,7 +103,6 @@ class Currency:
         fwd_curve_id (int): Id number of the forward curve of FX rates corresponding to this currency/FX pair.
         settle_curve_id (int): ID number of the settlement curve of FX rates corresponding to this currency/FX pair.
         unit_id (int): ID number corresponding to the unit of the currency, as defined on the KYOS platform. Typically, the generic "Currency" unit is applied to all FX-rates.
-
     """
 
     # constructor
@@ -151,16 +152,19 @@ class Currency:
 
 
 def make_currency(currency_dir: str = './Input/') -> list:
-    """Returns a list of all available currency objects in the input currency.csv file generated by the KYOS platform
+    """
+    Returns a list of all available currency objects in the input currency.csv file generated by the KYOS platform.
+
     Args:
         currency_dir (str): path to the directory
-    Return:
+
+    Returns:
         (list):  List of currency objects
 
     Note:
         CSV file called currency.csv must exist within the current working (project) directory. This file contains the relevant currency data.
 
-    Example:
+    Examples:
         >>> from kyoslib_py.settings import make_currency
         >>> currencies = make_currency()
         >>> currencies[0].name
@@ -183,11 +187,9 @@ class DstSwitchesSet:
 
     Attributes:
            commodities (list): list of objects
-
     """
 
     def __init__(self, dst_file_path: str = './Input/dst_switches.csv'):
-
         dst_file_path = Path(dst_file_path)
         if dst_file_path.exists() and os.stat(dst_file_path).st_size > 0:
             dst_switches_table = pd.read_csv(dst_file_path).values
@@ -216,7 +218,6 @@ class DstSwitchesSet:
 
                 dst_switches_per_timezone.append({"timezone_id": timezone_id, "dst_series": dst})
         else:
-
             dst_switches_per_timezone = [{"timezone_id": 0, "dst_series": pd.Series([])}]
 
         self.dst_switches_per_timezone = dst_switches_per_timezone
@@ -224,6 +225,7 @@ class DstSwitchesSet:
     def get_dst_moments(self, timezone_id: int) -> pd.Series:
         """
         This method gets the time dependent DST series.
+
         Args:
             timezone_id (int): id of the relevant timezone
 
@@ -250,7 +252,7 @@ class CommoditySet:
     Attributes:
            commodities (list): list of objects
 
-    Example:
+    Examples:
         >>> from kyoslib_py.settings import CommoditySet
         >>> commodity_set = CommoditySet.from_xml()
         >>> commodity = commodity_set.get_commodity(5)
@@ -260,13 +262,10 @@ class CommoditySet:
 
     def __init__(self, commodity_info_list, currency_set):
         """
-
         Args:
             commodity_info_list (list): this is a list of dictionaries. Each dictionary contains the commodity info for
                 a commodity object. This is the standard form in which a commodity is described, for example in the KYOS API.
-
             currency_set (CurrencySet): contains standard information about all currencies available in the KYOS platform.
-
         """
         # make a list of commodities that will be attached to the CommoditySet object
         self.commodities = []
@@ -289,10 +288,12 @@ class CommoditySet:
     ) -> object:
         """
         This method builds the CommoditySet object from a xml file.
+
         Args:
             xml_path: path to the xml file with commodity information
             currency_set: kyoslib.CurrencySet object
             calendar_set: kyoslib.CalendarSet object
+            dst_switches_set: object
 
         Returns:
             kyoslib.CommoditySet object
@@ -326,7 +327,7 @@ class CommoditySet:
             commodity_info['TradingCalendarID'] = int(
                 commodity_node.find('TradingCalendarID').text
             )
-            commodity_info['EnergyLHV'] = np.float(commodity_node.find('EnergyLHV').text)
+            commodity_info['EnergyLHV'] = float(commodity_node.find('EnergyLHV').text)
             commodity_info['TradingDayStart'] = int(commodity_node.find('TradingDayStart').text)
             commodity_info['UnitConversionType'] = int(
                 commodity_node.find('UnitConversionType').text
@@ -336,10 +337,10 @@ class CommoditySet:
             )
             commodity_info['TradablePeriod'] = int(commodity_node.find('TradablePeriod').text)
 
-            commodity_info['VolumeConversionFactor'] = np.float(
+            commodity_info['VolumeConversionFactor'] = float(
                 commodity_node.find('VolumeConversionFactor').text
             )
-            commodity_info['CarbonContent'] = np.float(commodity_node.find('CarbonContent').text)
+            commodity_info['CarbonContent'] = float(commodity_node.find('CarbonContent').text)
             TimeZoneId = int(commodity_node.find('TimezoneId').text)
             commodity_info['TimezoneId'] = TimeZoneId
             commodity_info['dst_switches'] = dst_switches_set.get_dst_moments(TimeZoneId)
@@ -372,7 +373,8 @@ class CommoditySet:
     def get_commodity_list(self) -> list:
         """
         This method can be used to a list of the commodities inside the commodity set
-        Return:
+
+        Returns:
             (list): each element is a KYOS commodity
 
         """
@@ -381,7 +383,8 @@ class CommoditySet:
     def get_commodity_id_list(self) -> list:
         """
         This method can be used to a list of ids of the commodities inside the commodity set
-        Return:
+
+        Returns:
             (list): each element is a KYOS commodity id
 
         """
@@ -389,10 +392,11 @@ class CommoditySet:
 
     def get_commodity(self, requested_commodity_id: int) -> object:
         """
-        Returns commodity object if commodity_id is found in the set of commodities
+        Returns commodity object if commodity_id is found in the set of commodities.
 
         Args:
             requested_commodity_id (int): commodity id from the server
+
         Returns:
             kyoslib.Commodity object or None
         """
@@ -435,7 +439,6 @@ class Commodity:
         carbon_content (float): Carbon content (kg/GJ)
         energy_lhw (float): lower heating value of a fuel commodity
         dst_switches (pd.Series): Series with dst switch moments for the commodity's timezone
-
     """
 
     # constructor
@@ -463,7 +466,6 @@ class Commodity:
         TradablePeriod: int,
         dst_switches: pd.Series,
     ):
-
         self.id = ID
         self.name = Name
         self.is_cent = IsCent
@@ -570,7 +572,7 @@ class Commodity:
             end_date (datetime): End date (sets time equal to 00:00:00).
             delivery_type_id (int): (optional) Delivery type ID (e.g. baseload=1, peakload=2). Default value is 1.
 
-        Return:
+        Returns:
             (tuple): tuple containing:
                 - (np.array): delivery_hours. Size: L-by-1 (where L is the number of time periods according to
                 output_granularity).
@@ -648,13 +650,14 @@ class Commodity:
         Returns the delivery hours and the delivery indicators between the start and end date
         granularity and for a given delivery type ID. Current implementation does not support to return delivery dates
         with the DST switches
+
         Args:
             del_period_id (int): delivery period/granularity of the dates (2-hour, 1 -half hour, 14 - quarter hour)
             start_date (datetime): Start date (sets time equal to 00:00:00).
             end_date (datetime): End date (sets time equal to 00:00:00).
             delivery_type_id (int): (optional) Delivery type ID (e.g. baseload=1, peakload=2). Default value is 1.
 
-        Return:
+        Returns:
             delivery_dates(np.array)(NDays x 24 x period_per_hour): calendar delivery date
             ind_delivery(np.array) (NDays x 24 x period_per_hour): true/false if delivery happens in this period
         """
@@ -714,7 +717,7 @@ class Commodity:
                 must be of type float, with value=1 (delivery) or value=0 (no delivery). Size: L-by-24, with L the
                 length of date_vector.
 
-        Return:
+        Returns:
             (np.array): Delivery matrix with adjusted delivery hours.
         """
         # error checking: delivery_matrix data type
@@ -792,14 +795,13 @@ def make_commodity(
     json_path: str = None,
     commodity_info_list: list = None,
 ) -> list:
-
     """
     Returns a list of all available commodity objects in the input xml file generated by the KYOS platform
 
-    Parameters:
+    Args:
         xml_path (str): Full path to xml file including name
 
-    Return:
+    Returns:
         (list): List of commodity objects
 
     Note:
@@ -807,7 +809,7 @@ def make_commodity(
         contains the commodity information.
         The make_currency function should be run before make_commodity
 
-    Example:
+    Examples:
         >>> from kyoslib_py.settings import make_commodity
         >>> commodity_set = make_commodity()
         >>> commodity_set[0].group_name
@@ -841,7 +843,6 @@ class DeliveryTypeSet:
     """
 
     def __init__(self, delivery_type_info_list: list = None) -> object:
-
         if delivery_type_info_list is None:
             # to be done, raise error
             return
@@ -854,6 +855,7 @@ class DeliveryTypeSet:
     @staticmethod
     def from_xml(xml_node: object = None, calendar_set: object = None) -> object:
         delivery_types_nodes = xml_node.findall('.//DeliveryTypes/')
+        delivery_types_nodes = [dtn for dtn in delivery_types_nodes if dtn.find('ID') != None]
         delivery_type_info_list = []
         nr_delivery_types = len(delivery_types_nodes)
         if nr_delivery_types != 0:
@@ -885,7 +887,6 @@ class DeliveryTypeSet:
         all_delivery_types = json_key
         delivery_type_info_list = []
         for delivery_type_dict in all_delivery_types:
-
             delivery_moments = delivery_type_dict['Days']
 
             delivery_type_info = dict()
@@ -959,14 +960,13 @@ class DeliveryType:
         delivery_type_node: object = None, delivery_type_dict=None, holiday_del_type=False
     ):
         """
-
         Args:
             delivery_type_node (object): node in XML tree containing info about delivery types
             delivery_type_dict (dict): dict containing info about delivery types
             holiday_del_type (bool): indicating if there is special delivery types on holidays. e.g. no peak on holidays
 
-        Return:
-            (dataframe): with delivery types
+        Returns:
+            (pd.DataFrame): with delivery types
         """
 
         def nr2bool(nr):
@@ -1076,7 +1076,7 @@ class DeliveryType:
                 must be of type boolean, with value=True (delivery) or value=False (no delivery). Size: L-by-24, with L
                 the length of date_vector.
 
-        Return:
+        Returns:
             (np.array): Delivery matrix with adjusted delivery hours.
         """
         # error checking: delivery_matrix data type
@@ -1107,6 +1107,7 @@ class CalendarSet:
     """
     This is the manager object of the Calendar class. A commodity can have multiple calendars. For example, a holiday calendar
     but also a bridge day calendar.
+
     Examples:
         >>> from kyoslib_py.settings import CalendarSet
         >>> calendar_set = CalendarSet.from_xml()
@@ -1116,7 +1117,6 @@ class CalendarSet:
     """
 
     def __init__(self, calendar_info_list: list = None):
-
         if calendar_info_list is None:
             # to be done raise error
             return
