@@ -22,9 +22,10 @@ def add_month_year(date, years=0, months=0):
             - (int): year_shift
             - (int): month_shift
 
-            Note:
-                * These can be used to build a new datetime.
-                * It is not clear how days/hours in a month should be shifted this case. Thus, no shifted day/hour is reported.
+    Note:
+        * These can be used to build a new datetime. \n
+        * It is not clear how days/hours in a month should be shifted in this case. Thus,
+        no shifted day/hour is reported.
     """
     year_orig = date.year
     month_orig = date.month
@@ -46,11 +47,11 @@ def shift_business_date(date, shift, trading_calendar=None):
             * shift = 2,  the second business day after the "date".
             * shift = -1, the first business day before the "date".
             * shift = -2, the business day before the business day prior to the "date".
-    trading_calendar (numpy array, optional): List of exchange holiday dates
+        trading_calendar (numpy array, optional): List of exchange holiday dates
             * holidays may influence start and end date of tradable products, such as BOM, week ahead.
             [(nHolidays x 1)]
 
-    Return:
+    Returns:
         (datetime): prev_date
     """
     if trading_calendar is None:
@@ -105,9 +106,6 @@ def get_start_end(
     Calculate the start/end dates of a tradable product(s).
     - Implementation is only for baseload (this should be extended in the future).
 
-    Todo:
-        We can add in the future an optional "delivery_period_name" to make this function more user friendly.
-
     Args:
         trading_date (datetime): trading date
         delivery_period (numpy array or list): products' delivery period, e.g. 5 = month, etc.
@@ -128,7 +126,7 @@ def get_start_end(
         use_gas_rules (bool, optional): should the European gas market rules be used to calculate the
             delivery period of tradable produts. They affect how day-ahead, BOW, BOM are calculated.
 
-    Return:
+    Returns:
         (list of datetimes): all_start_dates / all_end_dates (nProducts x 1): Start/End dates of each tradable product
             * if a product is not traded on the given trading date, then output NaN as start and end.
     """
@@ -445,6 +443,7 @@ def delivery_period_id_from_name(delivery_period_name: str) -> int:
 
     Args:
         delivery_period_name (str): granularity in string format, such as monthly or daily
+
     Returns:
         granularity_id (int) : KYOS platfrom's delivery type id
     """
