@@ -1,5 +1,6 @@
 """Functionality related to the KYOS platform valuation interface. It allows the transfer of data between different
 models within the platform."""
+
 import json
 from copy import deepcopy
 from pathlib import Path
@@ -47,7 +48,7 @@ class MetaData:
         comment,
     ):
         """
-        Args::
+        Args:
             isBuy (bool): Indicator that shows if the contract position is long (=true) or short (=false)
             isPhysical (bool): Indicator that shows if the contract is physical (=true) or financial (=false)
             entityID (int): ID number of the relevant entity
@@ -102,7 +103,7 @@ class CommData:
         Note that only the parameters of the constructor are assigned to the object when called, and the other attributes
         are populated using the set_data method.
 
-    Example:
+    Examples:
         >>> from kyoslib_py.valuation_interface
         >>> this_comm_data = CommData(commodity_id=2, forward_curve_id=33, currency_id=1,
                                 granularity=5)
@@ -148,7 +149,7 @@ class SimulationData:
         Note that only the parameters of the constructor are assigned to the object when called, and the other attributes
         are populated using the set_data method.
 
-    Example:
+    Examples:
         >>> from kyoslib_py.valuation_interface
         >>> this_sim_data = SimulationData(csv_filename='example.csv', type_output=['simulation'],
             type_calculation = ['simulation'] , dates=date_array, values=simulation_array)
@@ -189,7 +190,7 @@ class ValuationInterface:
         Only one DataInterface can be constructed at a time. Each new instance of the class is appended to the list class
         variable all_interfaces
 
-    Example:
+    Examples:
         >>> from kyoslib_py.valuation_interface import ValuationInterface
         >>> import datetime as dt
         >>> contract_output = ValuationInterface(model_name='Accumulator',
@@ -203,7 +204,8 @@ class ValuationInterface:
     all_interfaces = []
 
     def __init__(self, model_name, trading_date, folder, profile_id=None):
-        """Constructor of the ValuationInterface class.
+        """
+        Constructor of the ValuationInterface class.
 
         Args:
             model_name (str): Name of the model from which data is being saved
@@ -264,7 +266,7 @@ class ValuationInterface:
         Returns:
             (ValuationInterface): Instance of the ValuationInterface class object with CommData and/or SimulationData class instances appended
 
-        Example:
+        Examples:
             >>> import numpy as np
             >>> import datetime as dt
             >>> from kyoslib_py.valuation_interface import ValuationInterface
@@ -510,7 +512,7 @@ class ValuationInterface:
             commodity_id (int, optional):
                 Commodity ID of the data to be exported. If not provided, all data is exported to csv and JSON.
 
-        Example:
+        Examples:
             >>> import numpy as np
             >>> import datetime as dt
             >>> from kyoslib_py.valuation_interface import ValuationInterface
@@ -641,7 +643,7 @@ class ValuationInterface:
         Args:
             input_folder (str): Full path of directory where the metadata.json file is located, without trailing file separator
 
-        Example:
+        Examples:
             >>> from kyoslib_py.valuation_interface import ValuationInterface
             >>> contract_output = ValuationInterface(model_name='Accumulator',
             >>>                                      trading_date=dt.datetime(2020, 1, 1),
@@ -706,10 +708,11 @@ class ValuationInterface:
             data (dict):  a dictinary which conatins model specific information. e.g. accumulator object
             overwrite (bool): True, clear the dictonariy and append the new input,
                               False, append new input to the existing dictonary
+
         Returns:
             (ValuationInterface): Instance of the ValuationInterface class object with extra model data
 
-        Example:
+        Examples:
             >>> import datetime as dt
             >>> from kyoslib_py.valuation_interface import ValuationInterface
             >>> contract_output = ValuationInterface(model_name='KyAccumulator',
